
package presentacion;

import java.awt.CardLayout;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;

public class Componentes {
      
      private GestorEventos gestorEventos;  
      private JPanel jPanelPrincipal;
      private CardLayout cardLayout;
      private Opcion1 opcion1;
      private Opcion2 opcion2;
      private Opcion3 opcion3;
      private JButton jButtonOpcion1;
      private JLabel jLabelParcialOpcion1;
      private JLabel jLabelGlobalOpcion1;
      private JButton jButtonOpcion2;
      private JLabel jLabelParcialOpcion2; 
      private JLabel jLabelGlobalOpcion2;
      private JButton jButtonOpcion3;
      private JLabel jLabelParcialOpcion3;
      private JLabel jLabelGlobalOpcion3;
      private int contadorOpcion1 = 0;
      private int contadorOpcion2 = 0;
      private int contadorOpcion3 = 0;
      private int contadorGlobal = 0;
   
    public GestorEventos getGestorEventos() {
        return gestorEventos;
    }

    public void setGestorEventos(GestorEventos gestorEventos) {
        this.gestorEventos = gestorEventos;
    }
    
    public JPanel getjPanelPrincipal() {
        return jPanelPrincipal;
    }

    public void setjPanelPrincipal(JPanel jPanelPrincipal) {
        this.jPanelPrincipal = jPanelPrincipal;
    }

    public CardLayout getCardLayout() {
        return cardLayout;
    }

    public void setCardLayout(CardLayout cardLayout) {
        this.cardLayout = cardLayout;
    }
    
    public Opcion1 getOpcion1() {
        return opcion1;
    }

    public void setOpcion1(Opcion1 opcion1) {
        this.opcion1 = opcion1;
    }

    public Opcion2 getOpcion2() {
        return opcion2;
    }

    public void setOpcion2(Opcion2 opcion2) {
        this.opcion2 = opcion2;
    }

    public Opcion3 getOpcion3() {
        return opcion3;
    }

    public void setOpcion3(Opcion3 opcion3) {
        this.opcion3 = opcion3;
    }
    
    public JButton getjButtonOpcion1() {
        return jButtonOpcion1;
    }

    public void setjButtonOpcion1(JButton jButtonOpcion1) {
        this.jButtonOpcion1 = jButtonOpcion1;
    }

    public JLabel getjLabelParcialOpcion1() {
        return jLabelParcialOpcion1;
    }

    public void setjLabelParcialOpcion1(JLabel jLabelParcialOpcion1) {
        this.jLabelParcialOpcion1 = jLabelParcialOpcion1;
    }

    public JLabel getjLabelGlobalOpcion1() {
        return jLabelGlobalOpcion1;
    }

    public void setjLabelGlobalOpcion1(JLabel jLabelGlobalOpcion1) {
        this.jLabelGlobalOpcion1 = jLabelGlobalOpcion1;
    }

    public JButton getjButtonOpcion2() {
        return jButtonOpcion2;
    }

    public void setjButtonOpcion2(JButton jButtonOpcion2) {
        this.jButtonOpcion2 = jButtonOpcion2;
    }

    public JLabel getjLabelParcialOpcion2() {
        return jLabelParcialOpcion2;
    }

    public void setjLabelParcialOpcion2(JLabel jLabelParcialOpcion2) {
        this.jLabelParcialOpcion2 = jLabelParcialOpcion2;
    }

    public JLabel getjLabelGlobalOpcion2() {
        return jLabelGlobalOpcion2;
    }

    public void setjLabelGlobalOpcion2(JLabel jLabelGlobalOpcion2) {
        this.jLabelGlobalOpcion2 = jLabelGlobalOpcion2;
    }

    public JButton getjButtonOpcion3() {
        return jButtonOpcion3;
    }

    public void setjButtonOpcion3(JButton jButtonOpcion3) {
        this.jButtonOpcion3 = jButtonOpcion3;
    }

    public JLabel getjLabelParcialOpcion3() {
        return jLabelParcialOpcion3;
    }

    public void setjLabelParcialOpcion3(JLabel jLabelParcialOpcion3) {
        this.jLabelParcialOpcion3 = jLabelParcialOpcion3;
    }

    public JLabel getjLabelGlobalOpcion3() {
        return jLabelGlobalOpcion3;
    }

    public void setjLabelGlobalOpcion3(JLabel jLabelGlobalOpcion3) {
        this.jLabelGlobalOpcion3 = jLabelGlobalOpcion3;
    }

    public int getContadorOpcion1() {
        return contadorOpcion1;
    }

    public void setContadorOpcion1(int contadorOpcion1) {
        this.contadorOpcion1 = contadorOpcion1;
    }

    public int getContadorOpcion2() {
        return contadorOpcion2;
    }

    public void setContadorOpcion2(int contadorOpcion2) {
        this.contadorOpcion2 = contadorOpcion2;
    }

    public int getContadorOpcion3() {
        return contadorOpcion3;
    }

    public void setContadorOpcion3(int contadorOpcion3) {
        this.contadorOpcion3 = contadorOpcion3;
    }

    public int getContadorGlobal() {
        return contadorGlobal;
    }

    public void setContadorGlobal(int contadorGlobal) {
        this.contadorGlobal = contadorGlobal;
    }
}
