
package presentacion;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;

public class Opcion1 extends JPanel {
 
      private Componentes componentes;
      
    public Opcion1(Componentes componentes) {
        this.componentes = componentes;
        ubicarComponentes();
    }
     
    private void ubicarComponentes() {

        setLayout(null);        
                   // CONFIGURACIÓN JButton 
        componentes.setjButtonOpcion1(new JButton("Contar"));
        componentes.getjButtonOpcion1().setBounds(255, 220, 100, 40);  
        componentes.getjButtonOpcion1().setActionCommand("botonOpcion1");
        componentes.getjButtonOpcion1().addActionListener(componentes.getGestorEventos());   // REGISTRO DE ESCUCHA DE EVENTO DE BOTON
        add(componentes.getjButtonOpcion1());   
                   // CONFIGURACIÓN JLabel visualización contador parcial
        componentes.setjLabelParcialOpcion1(new JLabel());
        componentes.getjLabelParcialOpcion1().setBounds(100, 100, 400, 20);
        add(componentes.getjLabelParcialOpcion1()); 
                   // CONFIGURACIÓN JLabel visualización contador global
        componentes.setjLabelGlobalOpcion1(new JLabel());
        componentes.getjLabelGlobalOpcion1().setBounds(100, 150, 400, 20);
        add(componentes.getjLabelGlobalOpcion1());               
    }   
    
    public void iniciarPantalla() {
        componentes.setContadorOpcion1(0);
        componentes.getjLabelParcialOpcion1().setText("Pulsaciones botón opción 1:     "+componentes.getContadorOpcion1());
        componentes.getjLabelGlobalOpcion1().setText("Pulsaciones acumuladas de los botones de todas las opciones:     "+componentes.getContadorGlobal());
    }
}
